# _*_ coding: utf-8 _*_
#
# hspylib-datasource v0.9.74
#
# Package: main.datasource.firebase
"""Package initialization."""

__all__ = [
    'firebase_configuration', 
    'firebase_repository'
]
__version__ = '0.9.74'
